@@ -68,7 +68,7 @@
         n <- n - sum(gr.na)
         ## update labels
         labs <- labs[!gr.na]
-        warning("Missing observations due to 'group' removed.")
+        warning("missing observations due to 'group' removed")
     }
     ## remove NA's in d
     if(any(x.na <- apply(x, 1, function(x) any(is.na(x))))) {
@@ -78,7 +78,7 @@
         n <- n - sum(x.na)
         ## update labels
         labs <- labs[!x.na]
-        warning("Missing observations due to 'd' removed.")
+        warning("missing observations due to 'd' removed")
     }
     x <- x + t(x)
     x <- dblcen(x)
