@@ -2,6 +2,8 @@ intersetcor <- function(object)
 {
     if (!inherits(object, "cca"))
         stop("can be used only with objects inheriting from 'cca'")
+    if (is.null(object$CCA))
+        stop("can be used only with constrained ordination")
     wa <- object$CCA$wa
     if (!inherits(object, "rda")) {   # is CCA
         w <- object$rowsum
