@@ -17,12 +17,14 @@
         } else {
             ## input vector: either vectors or factors must be NULL,
             ## and the existing set of labels is replaced
-            if (!is.null(labs$v) && !is.null(labs$f))
+            if (!is.null(x$vectors) && !is.null(x$factors))
                 stop("needs a list with both 'vectors' and 'factors' labels")
-            if (!is.null(labs$v))
-                labs$v <- labels
-            else
+            ## need to handle the case where both sets of labels are NULL
+            ## such as when used with the default interface and single x
+            if (!is.null(x$factors))
                 labs$f <- labels
+            else
+                labs$v <- labels
         }
     }
     vect <- NULL
@@ -59,51 +61,67 @@
             ax <- -c(-1, 0, 1) * arrow.mul * maxarr
         }
         vect <- arrow.mul * vect
-        vtext <- sweep(1.1 * vect, 2, at, "+")
         vect <- sweep(vect, 2, at, "+")
+        if (add) {
+            vtext <- ordiArrowTextXY(vect, labs$v, ...)
+            vtext <- sweep(vtext, 2, at, "+")
+        }
     }
     if (!add) {
-        plot.new() ## needed for string widths and heights
-        if(!is.null(vect)) {
-            ## compute axis limits allowing space for labels
-            sw <- strwidth(labs$v, ...)
+        plot.new()
+        ## needed for string widths and heights We need dimensions to
+        ## fit completely the names of vectors and factors with no
+        ## clipping at axes. If there are (1) factors and vectors, we
+        ## need to adjust arrow lengths, if there are (2) only factors
+        ## or only vectors, we can use their scores directly. After
+        ## finding the scores, we must expand the scores by string
+        ## widths and heights. The expansion can be only estimated
+        ## after setting plot.window with its xlim and ylim, but we
+        ## need to find xlim and ylim to set the plot.window...
+
+        if(is.null(vect) || is.null(x$factors)) {
+            ## Only factors or vectors: set preliminary plot.window
+            xstack <- rbind(vect, x$factors$centroids)
+            plot.window(xlim = range(xstack[,1], at[1]),
+                        ylim = range(xstack[,2], at[2]),
+                        asp = 1, ...)
+        } else {
+            ## Both vectors and factors: set preliminary plot.window
+            ## from factors only and and find arrow.mul (which is
+            ## otherwise ## arrow.mul = 1)
+            plot.window(xlim = range(x$factors$centroids[,1], at[1]),
+                        ylim = range(x$factors$centroids[,2], at[2]),
+                        asp = 1, ...)
+            vfill <- 0.75
+            arrow.mul <- ordiArrowMul(vect, at = at, fill = 1)
+            vect <- arrow.mul * vect
+        }
+        ## Get string dimensions (width/2, height)
+        sw <- strwidth(c(labs$v, labs$f), ...) / 2
+        sh <- strheight(c(labs$v, labs$f), ...)
+        ## Reset limits
+        xstack <- rbind(x$factors$centroids, vect)
+        xlim <- range(xstack[,1] + sw, xstack[,2] - sw)
+        ylim <- range(xstack[,2] + sh, xstack[,2] - sh)
+        plot.window(xlim = xlim, ylim = ylim, asp = 1, ...)
+        ## Re-evaluate arrow.mul, set its text and re-evaluate limits again
+        if (!is.null(vect)) {
+            arrow.mul <- ordiArrowMul(vect, at = at, fill = 1)
+            vect <- arrow.mul * vect
+            vtext <- ordiArrowTextXY(vect, labs$v, ...)
+            sw <- strwidth(labs$v, ...) / 2
             sh <- strheight(labs$v, ...)
-            xlim <- range(at[1], vtext[,1] + sw, vtext[,1] - sw)
-            ylim <- range(at[2], vtext[,2] + sh, vtext[,2] - sh)
-            if(!is.null(x$factors)) {
-                ## if factors, also need to consider them
-                sw <- strwidth(labs$f, ...)
-                sh <- strheight(labs$f, ...)
-                xlim <- range(xlim, x$factors$centroids[, choices[1]] + sw,
-                              x$factors$centroids[, choices[1]] - sw)
-                ylim <- range(ylim, x$factors$centroids[, choices[2]] + sh,
-                              x$factors$centroids[, choices[2]] - sh)
-            }
-            ## these plotting calls will prob. generate warnings
-            ## because of passing ... everywhere. localFoo needed?
+            xlim <- range(xlim, vtext[,1] + sw, vtext[,1] - sw)
+            ylim <- range(xlim, vtext[,2] + sh, vtext[,2] - sh)
             plot.window(xlim = xlim, ylim = ylim, asp = 1, ...)
-            axis(side = 1, ...)
-            axis(side = 2, ...)
-            box(...)
-            alabs <- colnames(vect)
-            title(..., ylab = alabs[2], xlab = alabs[1])
-        } else if (!is.null(x$factors)) {
-            sw <- strwidth(labs$f, ...)
-            sh <- strheight(labs$f, ...)
-            xlim <- range(at[1], x$factors$centroids[, choices[1]] + sw,
-                          x$factors$centroids[, choices[1]] - sw)
-            ylim <- range(at[2], x$factors$centroids[, choices[2]] + sh,
-                          x$factors$centroids[, choices[2]] - sh)
-            ## these plotting calls will prob. generate warnings
-            ## because of passing ... everywhere. localFoo needed?
-            plot.window(xlim = xlim, ylim = ylim, asp = 1, ...)
-            axis(side = 1, ...)
-            axis(side = 2, ...)
-            box(...)
-            alabs <- colnames(x$factors$centroids[, choices, drop = FALSE])
-            title(..., ylab = alabs[2], xlab = alabs[1])
-        } else stop("Nothing to plot")
+        }
+        axis(side = 1, ...)
+        axis(side = 2, ...)
+        box(...)
+        alabs <- colnames(vect)
+        title(..., ylab = alabs[2], xlab = alabs[1])
     }
+
     if (!is.null(vect)) {
         arrows(at[1], at[2], vect[, 1], vect[, 2], len = 0.05,
                col = col)
