@@ -1,6 +1,7 @@
 `predict.rda` <-
     function (object, newdata, type = c("response", "wa", "sp", "lc", "working"), 
-              rank = "full", model = c("CCA", "CA"), scaling = FALSE, ...) 
+              rank = "full", model = c("CCA", "CA"), scaling = "none",
+              correlation = FALSE, ...) 
 {
     type <- match.arg(type)
     model <- match.arg(model)
@@ -24,6 +25,8 @@
     if (is.null(w)) 
         w <- u
     slam <- diag(sqrt(object[[model]]$eig[1:take] * nr), nrow = take)
+    ## process scaling arg, scaling used later so needs to be a numeric
+    scaling <- scalingType(scaling = scaling, correlation = correlation)
     if (type %in% c("response", "working")) {
         if (!missing(newdata)) {
             u <- predict(object, type = if(model == "CCA") "lc" else "wa",
@@ -75,7 +78,7 @@
             u <- u[, 1:take, drop = FALSE]
         }
         out <- u
-        if (scaling) {
+        if (scaling) {   # implicit coercion 0 == FALSE, other == TRUE
             tot <- sqrt(object$tot.chi * nr)
             lam <- list(diag(slam)/tot, 1, sqrt(diag(slam)/tot))[[abs(scaling)]]
             out <- sqrt(tot) * sweep(out, 2, lam, "*")
@@ -103,7 +106,7 @@
             w <- sweep(w, 2, diag(slam), "/")
         }
         out <- w
-        if (scaling) {
+        if (scaling) {   # implicit coercion 0 == FALSE, other == TRUE
             tot <- sqrt(object$tot.chi * nr)
             lam <- list(diag(slam)/tot, 1, sqrt(diag(slam)/tot))[[abs(scaling)]]
             out <- sqrt(tot) * sweep(out, 2, lam, "*")
@@ -127,7 +130,7 @@
             v <- sweep(v, 2, diag(slam), "/")
         }
         out <- v
-        if (scaling) {
+        if (scaling) {   # implicit coercion 0 == FALSE, other == TRUE
             tot <- sqrt(object$tot.chi * nr)
             scal <- list(1, diag(slam)/tot, sqrt(diag(slam)/tot))[[abs(scaling)]]
             out <- sqrt(tot) * sweep(out, 2, scal, "*")
